DisplaySize enum

Represents standard iOS device display sizes

Inheritance
Available extensions

Values

threeFive → const DisplaySize
const DisplaySize(3.5)
four → const DisplaySize
const DisplaySize(4.0)
fourSeven → const DisplaySize
const DisplaySize(4.7)
fiveFive → const DisplaySize
const DisplaySize(5.5)
sixOne → const DisplaySize
const DisplaySize(6.1)
sixThree → const DisplaySize
const DisplaySize(6.3)
sixFive → const DisplaySize
const DisplaySize(6.5)
sixNine → const DisplaySize
const DisplaySize(6.9)
nineSeven → const DisplaySize
const DisplaySize(9.7)
tenFive → const DisplaySize
const DisplaySize(10.5)
eleven → const DisplaySize
const DisplaySize(11.0)
twelveNine → const DisplaySize
const DisplaySize(12.9)
thirteen → const DisplaySize
const DisplaySize(13.0)

Properties

hashCode → int
The hash code for this object.
no setterinherited
inches → double
final
index → int
A numeric identifier for the enumerated value.
no setterinherited
label → String
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<DisplaySize>
A constant List of the values in this enum, in order of their declaration.