ScreenshotSource enum
What a screenshot's image was made from.
Values
- app → const ScreenshotSource
-
A capture of the running app.
- widget → const ScreenshotSource
-
A widget rendered on its own, such as a hero slide.
- poster → const ScreenshotSource
-
A frame with no device: background, caption and decorations.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ScreenshotSource> - A constant List of the values in this enum, in order of their declaration.