device library
Copyright 2019-2020 eBay Inc.
Use of this source code is governed by a BSD-style license that can be found in the LICENSE file or at https://opensource.org/licenses/BSD-3-Clause
Classes
Enums
- DevicePlatform
- DeviceType
- The kind of device a Device is. Store upload folders that sort screenshots by kind, such as fastlane supply's, use it.
- DisplaySize
- Represents standard iOS device display sizes